==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapResourceServerEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapResourceServerEntity.AbstractMapResourceServerEntity implements org.keycloak.models.map.authorization.entity.MapResourceServerEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> entityFieldDelegate;
    public MapResourceServerEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAllowRemoteResourceManagement() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setAllowRemoteResourceManagement(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode getPolicyEnforcementMode() {
        return (org.keycloak.representations.idm.authorization.PolicyEnforcementMode) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE);
    }
    @SuppressWarnings("unchecked") @Override public void setPolicyEnforcementMode(org.keycloak.representations.idm.authorization.PolicyEnforcementMode p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return (org.keycloak.representations.idm.authorization.DecisionStrategy) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY);
    }
    @SuppressWarnings("unchecked") @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceServerEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapResourceServerEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapResourceServerEntity.AbstractMapResourceServerEntity implements org.keycloak.models.map.authorization.entity.MapResourceServerEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> entityFieldDelegate;
    public MapResourceServerEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceServerEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAllowRemoteResourceManagement() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setAllowRemoteResourceManagement(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.ALLOW_REMOTE_RESOURCE_MANAGEMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.PolicyEnforcementMode getPolicyEnforcementMode() {
        return (org.keycloak.representations.idm.authorization.PolicyEnforcementMode) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE);
    }
    @SuppressWarnings("unchecked") @Override public void setPolicyEnforcementMode(org.keycloak.representations.idm.authorization.PolicyEnforcementMode p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.POLICY_ENFORCEMENT_MODE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.representations.idm.authorization.DecisionStrategy getDecisionStrategy() {
        return (org.keycloak.representations.idm.authorization.DecisionStrategy) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY);
    }
    @SuppressWarnings("unchecked") @Override public void setDecisionStrategy(org.keycloak.representations.idm.authorization.DecisionStrategy p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceServerEntityFields.DECISION_STRATEGY, p0);
    }
}
